summaryrefslogtreecommitdiff
path: root/editeng/source/items
diff options
context:
space:
mode:
authorChris Sherlock <chris.sherlock79@gmail.com>2016-01-29 17:43:42 +1100
committerChris Sherlock <chris.sherlock79@gmail.com>2016-01-31 04:31:13 +0000
commit3187193a6142b4b1c974ae1e1de572fa74a3c8ee (patch)
tree6d9350492186d06a38703821336ba79cb72a8583 /editeng/source/items
parent0bc3af3c1f719f9758ac01ff0b526abea7af0490 (diff)
tools: rename FontUnderline to FontLineStyle
Change-Id: I4750ad8569a1003b2f8c29052f3e25003ee433ca Reviewed-on: https://gerrit.libreoffice.org/21892 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Chris Sherlock <chris.sherlock79@gmail.com>
Diffstat (limited to 'editeng/source/items')
-rw-r--r--editeng/source/items/bulitem.cxx2
-rw-r--r--editeng/source/items/svxfont.cxx4
-rw-r--r--editeng/source/items/textitem.cxx28
3 files changed, 17 insertions, 17 deletions
diff --git a/editeng/source/items/bulitem.cxx b/editeng/source/items/bulitem.cxx
index 2f258620279c..8b41023f79f2 100644
--- a/editeng/source/items/bulitem.cxx
+++ b/editeng/source/items/bulitem.cxx
@@ -75,7 +75,7 @@ vcl::Font SvxBulletItem::CreateFont( SvStream& rStream, sal_uInt16 nVer )
rStream.ReadUInt16( nTemp ); aFont.SetPitch((FontPitch)nTemp);
rStream.ReadUInt16( nTemp ); aFont.SetAlignment((FontAlign)nTemp);
rStream.ReadUInt16( nTemp ); aFont.SetWeight((FontWeight)nTemp);
- rStream.ReadUInt16( nTemp ); aFont.SetUnderline((FontUnderline)nTemp);
+ rStream.ReadUInt16( nTemp ); aFont.SetUnderline((FontLineStyle)nTemp);
rStream.ReadUInt16( nTemp ); aFont.SetStrikeout((FontStrikeout)nTemp);
rStream.ReadUInt16( nTemp ); aFont.SetItalic((FontItalic)nTemp);
diff --git a/editeng/source/items/svxfont.cxx b/editeng/source/items/svxfont.cxx
index 1cacdbedc89b..83b21f675859 100644
--- a/editeng/source/items/svxfont.cxx
+++ b/editeng/source/items/svxfont.cxx
@@ -693,9 +693,9 @@ void SvxDoDrawCapital::Do( const OUString &_rTxt, const sal_Int32 _nIdx,
Size aPartSize;
// Set the desired font
- FontUnderline eUnder = pFont->GetUnderline();
+ FontLineStyle eUnder = pFont->GetUnderline();
FontStrikeout eStrike = pFont->GetStrikeout();
- pFont->SetUnderline( UNDERLINE_NONE );
+ pFont->SetUnderline( LINESTYLE_NONE );
pFont->SetStrikeout( STRIKEOUT_NONE );
if ( !bUpper )
{
diff --git a/editeng/source/items/textitem.cxx b/editeng/source/items/textitem.cxx
index 4806948d0615..218cb2b6def9 100644
--- a/editeng/source/items/textitem.cxx
+++ b/editeng/source/items/textitem.cxx
@@ -107,9 +107,9 @@ SfxPoolItem* SvxPostureItem::CreateDefault() { return new SvxPostureItem(ITALIC_
SfxPoolItem* SvxWeightItem::CreateDefault() {return new SvxWeightItem(WEIGHT_NORMAL, 0);}
SfxPoolItem* SvxFontHeightItem::CreateDefault() {return new SvxFontHeightItem(240, 100, 0);}
SfxPoolItem* SvxFontWidthItem::CreateDefault() {return new SvxFontWidthItem(0, 100, 0);}
-SfxPoolItem* SvxTextLineItem::CreateDefault() {return new SvxTextLineItem(UNDERLINE_NONE, 0);}
-SfxPoolItem* SvxUnderlineItem::CreateDefault() {return new SvxUnderlineItem(UNDERLINE_NONE, 0);}
-SfxPoolItem* SvxOverlineItem::CreateDefault() {return new SvxOverlineItem(UNDERLINE_NONE, 0);}
+SfxPoolItem* SvxTextLineItem::CreateDefault() {return new SvxTextLineItem(LINESTYLE_NONE, 0);}
+SfxPoolItem* SvxUnderlineItem::CreateDefault() {return new SvxUnderlineItem(LINESTYLE_NONE, 0);}
+SfxPoolItem* SvxOverlineItem::CreateDefault() {return new SvxOverlineItem(LINESTYLE_NONE, 0);}
SfxPoolItem* SvxCrossedOutItem::CreateDefault() {return new SvxCrossedOutItem(STRIKEOUT_NONE, 0);}
SfxPoolItem* SvxShadowedItem::CreateDefault() {return new SvxShadowedItem(false, 0);}
SfxPoolItem* SvxAutoKernItem::CreateDefault() {return new SvxAutoKernItem(false, 0);}
@@ -1250,7 +1250,7 @@ bool SvxFontWidthItem::GetPresentation
// class SvxTextLineItem ------------------------------------------------
-SvxTextLineItem::SvxTextLineItem( const FontUnderline eSt, const sal_uInt16 nId )
+SvxTextLineItem::SvxTextLineItem( const FontLineStyle eSt, const sal_uInt16 nId )
: SfxEnumItem( nId, (sal_uInt16)eSt ), mColor( COL_TRANSPARENT )
{
}
@@ -1266,14 +1266,14 @@ bool SvxTextLineItem::HasBoolValue() const
bool SvxTextLineItem::GetBoolValue() const
{
- return (FontUnderline)GetValue() != UNDERLINE_NONE;
+ return (FontLineStyle)GetValue() != LINESTYLE_NONE;
}
void SvxTextLineItem::SetBoolValue( bool bVal )
{
- SetValue( (sal_uInt16)(bVal ? UNDERLINE_SINGLE : UNDERLINE_NONE) );
+ SetValue( (sal_uInt16)(bVal ? LINESTYLE_SINGLE : LINESTYLE_NONE) );
}
@@ -1289,7 +1289,7 @@ SfxPoolItem* SvxTextLineItem::Clone( SfxItemPool * ) const
sal_uInt16 SvxTextLineItem::GetValueCount() const
{
- return UNDERLINE_DOTTED + 1; // UNDERLINE_NONE also belongs here
+ return LINESTYLE_DOTTED + 1; // LINESTYLE_NONE also belongs here
}
@@ -1306,7 +1306,7 @@ SfxPoolItem* SvxTextLineItem::Create(SvStream& rStrm, sal_uInt16) const
{
sal_uInt8 nState;
rStrm.ReadUChar( nState );
- return new SvxTextLineItem( (FontUnderline)nState, Which() );
+ return new SvxTextLineItem( (FontLineStyle)nState, Which() );
}
@@ -1404,7 +1404,7 @@ bool SvxTextLineItem::operator==( const SfxPoolItem& rItem ) const
// class SvxUnderlineItem ------------------------------------------------
-SvxUnderlineItem::SvxUnderlineItem( const FontUnderline eSt, const sal_uInt16 nId )
+SvxUnderlineItem::SvxUnderlineItem( const FontLineStyle eSt, const sal_uInt16 nId )
: SvxTextLineItem( eSt, nId )
{
}
@@ -1424,20 +1424,20 @@ SfxPoolItem* SvxUnderlineItem::Create(SvStream& rStrm, sal_uInt16) const
{
sal_uInt8 nState;
rStrm.ReadUChar( nState );
- return new SvxUnderlineItem( (FontUnderline)nState, Which() );
+ return new SvxUnderlineItem( (FontLineStyle)nState, Which() );
}
OUString SvxUnderlineItem::GetValueTextByPos( sal_uInt16 nPos ) const
{
- DBG_ASSERT( nPos <= (sal_uInt16)UNDERLINE_BOLDWAVE, "enum overflow!" );
+ DBG_ASSERT( nPos <= (sal_uInt16)LINESTYLE_BOLDWAVE, "enum overflow!" );
return EE_RESSTR(RID_SVXITEMS_UL_BEGIN + nPos);
}
// class SvxOverlineItem ------------------------------------------------
-SvxOverlineItem::SvxOverlineItem( const FontUnderline eSt, const sal_uInt16 nId )
+SvxOverlineItem::SvxOverlineItem( const FontLineStyle eSt, const sal_uInt16 nId )
: SvxTextLineItem( eSt, nId )
{
}
@@ -1457,14 +1457,14 @@ SfxPoolItem* SvxOverlineItem::Create(SvStream& rStrm, sal_uInt16) const
{
sal_uInt8 nState;
rStrm.ReadUChar( nState );
- return new SvxOverlineItem( (FontUnderline)nState, Which() );
+ return new SvxOverlineItem( (FontLineStyle)nState, Which() );
}
OUString SvxOverlineItem::GetValueTextByPos( sal_uInt16 nPos ) const
{
- DBG_ASSERT( nPos <= (sal_uInt16)UNDERLINE_BOLDWAVE, "enum overflow!" );
+ DBG_ASSERT( nPos <= (sal_uInt16)LINESTYLE_BOLDWAVE, "enum overflow!" );
return EE_RESSTR(RID_SVXITEMS_OL_BEGIN + nPos);
}